from setuptools import setup, find_packages

setup(
    name='ICBCPackageNDKT',
    version='1.0',
    packages=find_packages(exclude=['tests*']),
    license='MIT',
    description='A test ICBC python package',
	url='https://github.com/ubco-mds-2022-labs/project-step-2-kcmtong.git',
    author='Nowshaba Durrani & Kenny Tong',
    author_email='nowshaba@gmail.com'
)
